diff rhodecode/lib/vcs/backends/base.py @ 3492:0065f7fe60f6 beta

fix spelling of committer
author Mads Kiilerich <madski@unity3d.com>
date Wed, 06 Mar 2013 19:54:36 +0100
parents 951aa2741c98
children 58905069da21
line wrap: on
line diff
--- a/rhodecode/lib/vcs/backends/base.py	Wed Mar 06 15:40:58 2013 +0100
+++ b/rhodecode/lib/vcs/backends/base.py	Wed Mar 06 19:54:36 2013 +0100
@@ -454,28 +454,28 @@
         raise NotImplementedError
 
     @LazyProperty
-    def commiter(self):
+    def committer(self):
         """
         Returns Commiter for given commit
         """
 
         raise NotImplementedError
 
     @LazyProperty
-    def commiter_name(self):
+    def committer_name(self):
         """
         Returns Author name for given commit
         """
 
-        return author_name(self.commiter)
+        return author_name(self.committer)
 
     @LazyProperty
-    def commiter_email(self):
+    def committer_email(self):
         """
         Returns Author email address for given commit
         """
 
-        return author_email(self.commiter)
+        return author_email(self.committer)
 
     @LazyProperty
     def author(self):
@@ -454,28 +454,28 @@
         """
-        Returns Commiter for given commit
+        Returns Committer for given commit
         """
 